@@ -7,8 +7,6 @@ import timeit
 import codefast as cf
 import requests
 from colorama import Back, Fore, Style
-from codefast.logger import setpath
-setpath('/tmp/endlessh.log')
 
 
 class Hosts(object):
@@ -46,7 +44,7 @@ async def handler(_reader, writer):
                 Hosts.peer[peer] = timeit.default_timer()
                 loc = Hosts.get_location(peer.split(':')[0])
                 cf.info('connection from peer {}, {}'.format(
-                    peer, Fore.LIGHTMAGENTA_EX + loc))
+                    peer, Fore.LIGHTMAGENTA_EX + loc + Style.RESET_ALL))
             writer.write(b'%x\r\n' % random.randint(0, 2**32))
             if int(peer.split(':').pop()) < 10000 and random.randint(
                     0, 100) == 63:
